@@ -48,7 +48,7 @@ globalVariables("private")
 #'
 #' @param reporter A testthat reporter to wrap into a new `CleanupReporter`
 #'   class.
-#' @return New reporter class  that behaves exactly like `reporter`,
+#' @return New reporter class that behaves exactly like `reporter`,
 #'   but it checks for, and optionally cleans up child processes, at the
 #'   specified granularity.
 #'
@@ -224,14 +224,16 @@ CleanupReporter <- function(reporter = testthat::ProgressReporter) {
           new <- ps_connections(ps_handle())[, 1:6]
           ## This is a connection that is used internally on macOS,
           ## for DNS resolution. We'll just ignore it. Looks like this:
-          ## # A tibble: 2 x 6
+          ## # A data frame: 2 x 6
           ##    fd family  type        laddr lport raddr
           ## <int> <chr>   <chr>       <chr> <int> <chr>
           ##     7 AF_UNIX SOCK_STREAM <NA>     NA /var/run/mDNSResponder
           ##    10 AF_UNIX SOCK_STREAM <NA>     NA /var/run/mDNSResponder
           new <- new[
-            new$family != "AF_UNIX" | new$type != "SOCK_STREAM" |
-            tolower(basename(new$raddr)) != "mdnsresponder", ]
+            new$family != "AF_UNIX" |
+            new$type != "SOCK_STREAM" |
+            is.na(new$raddr) |
+            paste(tolower(basename(new$raddr))) != "mdnsresponder", ]
 
           leftover <- ! apply(new, 1, paste, collapse = "&") %in%
             apply(old, 1, paste, collapse = "&")
