@@ -21,6 +21,8 @@
 #include "ps-internal.h"
 #include "arch/macos/process_info.h"
 
+#include <stdbool.h>
+
 #define PS__TV2DOUBLE(t) ((t).tv_sec + (t).tv_usec / 1000000.0)
 
 #define PS__CHECK_KINFO(kp, handle)				      \
@@ -771,7 +773,7 @@ SEXP psll_connections(SEXP p) {
 
 	// check for inet_ntop failures
 	if (errno != 0) {
-	  ps__set_error_from_errno(0);
+	  ps__set_error_from_errno();
 	  goto error;
 	}
 
